@@ -60,14 +60,6 @@ typedef struct perl_libpng
     /* If the following variable is set to a true value, the module
        prints messages about what it is doing. */
     int verbosity : 1;
-    /* If the following variable is set to a true value, the module
-       raises an error (die) if there is an error other than something
-       being undefined. */
-    int raise_errors : 1;
-    /* Print error messages. */
-    int print_errors : 1;
-    /* Print a message on STDERR if something is undefined. */
-    int print_undefined : 1;
     /* Has input/output been initiated? */
     int init_io_done : 1;
 }
@@ -1461,7 +1453,7 @@ static SV * perl_png_get_tRNS (perl_libpng_t * png)
     else {
 	HV * trans_hv;
 	trans_hv = newHV ();
-#line 1464 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 1456 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
         
 	HASH_STORE_IV_MEMBER (trans_hv, red, trans_values);
 	
@@ -1471,7 +1463,7 @@ static SV * perl_png_get_tRNS (perl_libpng_t * png)
 	
 	HASH_STORE_IV_MEMBER (trans_hv, gray, trans_values);
 	
-#line 1469 "perl-libpng.c.tmpl"
+#line 1461 "perl-libpng.c.tmpl"
 	return newRV_noinc ((SV *) trans_hv);
     }
 #else
@@ -1525,7 +1517,7 @@ static void perl_png_set_tRNS (perl_libpng_t * png, SV * tRNS)
 	    /* unhandled error */
 	}
 	trans_hv = (HV *) SvRV (tRNS);
-#line 1528 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 1520 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
         
 	    HASH_FETCH_IV_MEMBER (trans_hv, red, (& trans_values));
 	
@@ -1535,7 +1527,7 @@ static void perl_png_set_tRNS (perl_libpng_t * png, SV * tRNS)
 	
 	    HASH_FETCH_IV_MEMBER (trans_hv, gray, (& trans_values));
 	
-#line 1527 "perl-libpng.c.tmpl"
+#line 1519 "perl-libpng.c.tmpl"
 	num_trans = 1;
 	png_set_tRNS (pngi, trans, num_trans, & trans_values); 
     }
@@ -1563,14 +1555,14 @@ perl_png_spalette_to_hv (png_sPLT_tp spalette)
 	png_sPLT_entry * entry;
 	entry = spalette->entries + i;
 	perl_entry = newHV ();
-#line 1566 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 1558 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
 		HASH_STORE_IV_MEMBER (perl_entry, red, entry);
 		HASH_STORE_IV_MEMBER (perl_entry, green, entry);
 		HASH_STORE_IV_MEMBER (perl_entry, blue, entry);
 		HASH_STORE_IV_MEMBER (perl_entry, alpha, entry);
 		HASH_STORE_IV_MEMBER (perl_entry, frequency, entry);
 	
-#line 1559 "perl-libpng.c.tmpl"
+#line 1551 "perl-libpng.c.tmpl"
 	av_push (entries, newRV_noinc ((SV *) perl_entry));
     }
     HASH_STORE_AV (perl_spalette, entries);
@@ -1674,14 +1666,14 @@ static void perl_png_set_sPLT (perl_libpng_t * png, AV * sPLT_entries)
 	    }
 	    MESSAGE ("Copying entry %d", j);
 	    e = entry->entries + j;
-#line 1677 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 1669 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
  	    	    HASH_FETCH_IV_MEMBER (perl_entry, red, e);
 	    	    HASH_FETCH_IV_MEMBER (perl_entry, green, e);
 	    	    HASH_FETCH_IV_MEMBER (perl_entry, blue, e);
 	    	    HASH_FETCH_IV_MEMBER (perl_entry, alpha, e);
 	    	    HASH_FETCH_IV_MEMBER (perl_entry, frequency, e);
 	    
-#line 1667 "perl-libpng.c.tmpl"
+#line 1659 "perl-libpng.c.tmpl"
 	}
     }
     MESSAGE ("Setting the entries");
@@ -2000,9 +1992,9 @@ static SV * perl_png_get_valid (perl_libpng_t * png)
     valid = png_get_valid (pngi, 0xFFFFFFFF);
 #define V(x) \
     (void) hv_store (perl_valid, #x, strlen (#x), newSViv (valid & PNG_INFO_ ## x), 0)
-#line 2003 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 1995 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
 V(bKGD);V(cHRM);V(gAMA);V(hIST);V(iCCP);V(IDAT);V(oFFs);V(pCAL);V(pHYs);V(PLTE);V(sBIT);V(sCAL);V(sPLT);V(sRGB);V(tIME);V(tRNS);
-#line 1976 "perl-libpng.c.tmpl"
+#line 1968 "perl-libpng.c.tmpl"
 #undef V
 
     return newRV_noinc ((SV *) perl_valid);
@@ -2374,7 +2366,7 @@ static void perl_png_set_unknown_chunks (perl_libpng_t * png, AV * chunk_list)
 
 int perl_png_libpng_supports (const char * what)
 {
-#line 2377 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 2369 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
     if (strcmp (what, "16BIT") == 0) {
 #ifdef PNG_16BIT_SUPPORTED
         return 1;
@@ -3285,7 +3277,7 @@ int perl_png_libpng_supports (const char * what)
         return 0;
 #endif /* zTXt */
     }
-#line 2358 "perl-libpng.c.tmpl"
+#line 2350 "perl-libpng.c.tmpl"
 
     /* sCAL is a special case. */
 
@@ -3384,7 +3376,7 @@ static SV * perl_png_get_cHRM (perl_libpng_t * png)
 #ifdef PNG_cHRM_SUPPORTED
     if (VALID (cHRM)) {
         HV * ice;
-#line 3387 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 3379 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
         double white_x;
         double white_y;
         double red_x;
@@ -3393,10 +3385,10 @@ static SV * perl_png_get_cHRM (perl_libpng_t * png)
         double green_y;
         double blue_x;
         double blue_y;
-#line 2456 "perl-libpng.c.tmpl"
+#line 2448 "perl-libpng.c.tmpl"
         png_get_cHRM (pngi , & white_x, & white_y, & red_x, & red_y, & green_x, & green_y, & blue_x, & blue_y);
         ice = newHV ();
-#line 3399 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 3391 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
         (void) hv_store (ice, "white_x", strlen ("white_x"),
                          newSVnv (white_x), 0);
         (void) hv_store (ice, "white_y", strlen ("white_y"),
@@ -3413,7 +3405,7 @@ static SV * perl_png_get_cHRM (perl_libpng_t * png)
                          newSVnv (blue_x), 0);
         (void) hv_store (ice, "blue_y", strlen ("blue_y"),
                          newSVnv (blue_y), 0);
-#line 2465 "perl-libpng.c.tmpl"
+#line 2457 "perl-libpng.c.tmpl"
         chrm = newRV_noinc ((SV *) ice);
     }
 #else
@@ -3427,7 +3419,7 @@ static void perl_png_set_cHRM (perl_libpng_t * png, HV * cHRM)
 {
 #ifdef PNG_cHRM_SUPPORTED
     SV ** key_sv_ptr;
-#line 3430 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 3422 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
     double white_x = 0.0;
     double white_y = 0.0;
     double red_x = 0.0;
@@ -3468,9 +3460,9 @@ static void perl_png_set_cHRM (perl_libpng_t * png, HV * cHRM)
     if (key_sv_ptr) {
         blue_y = SvNV (* key_sv_ptr);
     }
-#line 2489 "perl-libpng.c.tmpl"
+#line 2481 "perl-libpng.c.tmpl"
     png_set_cHRM (pngi, white_x, white_y, red_x, red_y, green_x, green_y, blue_x, blue_y);
-#line 2492 "perl-libpng.c.tmpl"
+#line 2484 "perl-libpng.c.tmpl"
 #else
     /* libpng was compiled without this option. */
     UNSUPPORTED(cHRM);
@@ -3504,7 +3496,7 @@ static void perl_png_copy_row_pointers (perl_libpng_t * png, SV * row_pointers)
     png_set_rows (pngi, png->row_pointers);
 }
 
-#line 3507 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 3499 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
 
 static int
 perl_png_get_image_width (perl_libpng_t * png)
@@ -3518,7 +3510,7 @@ perl_png_get_image_height (perl_libpng_t * png)
     return png_get_image_height (pngi);
 }
 
-#line 2534 "perl-libpng.c.tmpl"
+#line 2526 "perl-libpng.c.tmpl"
 
 
 static void
